@@ -10,6 +10,7 @@ from __future__ import absolute_import, division, print_function
 
 import os
 
+from docx.enum.section import WD_SECTION
 from docx.enum.text import WD_BREAK
 from docx.opc.constants import CONTENT_TYPE as CT, RELATIONSHIP_TYPE as RT
 from docx.package import Package
@@ -100,6 +101,15 @@ class Document(object):
 
         return picture
 
+    def add_section(self, start_type=WD_SECTION.NEW_PAGE):
+        """
+        Return a |Section| object representing a new section added at the end
+        of the document. The optional *start_type* argument must be a member
+        of the :ref:`WdSectionStart` enumeration defaulting to
+        ``WD_SECTION.NEW_PAGE`` if not provided.
+        """
+        return self._document_part.add_section(start_type)
+
     def add_table(self, rows, cols, style='LightShading-Accent1'):
         """
         Add a table having row and column counts of *rows* and *cols*
@@ -147,6 +157,13 @@ class Document(object):
         """
         self._package.save(path_or_stream)
 
+    @property
+    def sections(self):
+        """
+        Return a reference to the |Sections| instance for this document.
+        """
+        return self._document_part.sections
+
     @lazyproperty
     def styles_part(self):
         """
