@@ -6,7 +6,7 @@ Text-related proxy types for python-docx, such as Paragraph and Run.
 
 from __future__ import absolute_import, print_function, unicode_literals
 
-from docx.enum.text import WD_BREAK
+from docx.enum.text import WD_BREAK, WD_UNDERLINE
 
 
 def boolproperty(f):
@@ -20,12 +20,12 @@ def boolproperty(f):
         return getattr(parent, attr_name)
 
     def _remove_prop(parent, attr_name):
-        remove_method_name = 'remove_%s' % attr_name
+        remove_method_name = '_remove_%s' % attr_name
         remove_method = getattr(parent, remove_method_name)
         remove_method()
 
     def _add_prop(parent, attr_name):
-        add_method_name = 'add_%s' % attr_name
+        add_method_name = '_add_%s' % attr_name
         add_method = getattr(parent, add_method_name)
         return add_method()
 
@@ -333,19 +333,22 @@ class Run(object):
     def underline(self):
         """
         The underline style for this |Run|, one of |None|, |True|, |False|,
-        or a value from ``pptx.enum.text.WD_UNDERLINE``. A value of |None|
-        indicates the run has no directly-applied underline value and so will
-        inherit the underline value of its containing paragraph. Assigning
-        |None| to this property removes any directly-applied underline value.
-        A value of |False| indicates a directly-applied setting of no
-        underline, overriding any inherited value. A value of |True|
-        indicates single underline. The values from ``WD_UNDERLINE`` are used
-        to specify other outline styles such as double, wavy, and dotted.
+        or a value from :ref:`WdUnderline`. A value of |None| indicates the
+        run has no directly-applied underline value and so will inherit the
+        underline value of its containing paragraph. Assigning |None| to this
+        property removes any directly-applied underline value. A value of
+        |False| indicates a directly-applied setting of no underline,
+        overriding any inherited value. A value of |True| indicates single
+        underline. The values from ``WD_UNDERLINE`` are used to specify other
+        outline styles such as double, wavy, and dotted.
         """
         return self._r.underline
 
     @underline.setter
     def underline(self, value):
+        if not WD_UNDERLINE.is_valid_setting(value):
+            tmpl = "'%s' is not a valid setting for Run.underline"
+            raise ValueError(tmpl % value)
         self._r.underline = value
 
     @boolproperty
