@@ -17,6 +17,7 @@ from docx.package import Package
 from docx.parts.document import DocumentPart, InlineShapes
 from docx.parts.numbering import NumberingPart
 from docx.parts.styles import StylesPart
+from docx.section import Section
 from docx.table import Table
 from docx.text import Paragraph, Run
 
@@ -96,6 +97,14 @@ class DescribeDocument(object):
         assert picture.height == expected_height
         assert picture is picture_
 
+    def it_can_add_a_section(self, add_section_fixture):
+        document, start_type_, section_ = add_section_fixture
+        section = document.add_section(start_type_)
+        document._document_part.add_section.assert_called_once_with(
+            start_type_
+        )
+        assert section is section_
+
     def it_can_add_a_table(self, add_table_fixture):
         document, rows, cols, style, document_part_, expected_style, table_ = (
             add_table_fixture
@@ -115,6 +124,10 @@ class DescribeDocument(object):
         paragraphs = document.paragraphs
         assert paragraphs is paragraphs_
 
+    def it_provides_access_to_the_document_sections(self, document):
+        body = document.sections
+        assert body is document._document_part.sections
+
     def it_provides_access_to_the_document_tables(self, tables_fixture):
         document, tables_ = tables_fixture
         tables = document.tables
@@ -163,6 +176,10 @@ class DescribeDocument(object):
 
     # fixtures -------------------------------------------------------
 
+    @pytest.fixture
+    def add_empty_paragraph_fixture(self, document, document_part_, p_):
+        return document, document_part_, p_
+
     @pytest.fixture(params=[0, 1, 2, 5, 9])
     def add_heading_fixture(self, request, document, add_paragraph_, p_):
         level = request.param
@@ -170,20 +187,10 @@ class DescribeDocument(object):
         style = 'Title' if level == 0 else 'Heading%d' % level
         return document, add_paragraph_, p_, text, level, style
 
-    @pytest.fixture
-    def add_empty_paragraph_fixture(self, document, document_part_, p_):
-        return document, document_part_, p_
-
     @pytest.fixture
     def add_page_break_fixture(self, document, document_part_, p_, r_):
         return document, document_part_, p_, r_
 
-    @pytest.fixture
-    def add_paragraph_(self, request, p_):
-        return method_mock(
-            request, Document, 'add_paragraph', return_value=p_
-        )
-
     @pytest.fixture(params=[
         (None, None,  200,  100),
         (1000, 500,  1000,  500),
@@ -202,6 +209,10 @@ class DescribeDocument(object):
             expected_width, expected_height, picture_
         )
 
+    @pytest.fixture
+    def add_section_fixture(self, document, start_type_, section_):
+        return document, start_type_, section_
+
     @pytest.fixture
     def add_styled_paragraph_fixture(self, document, p_):
         style = 'foobaresque'
@@ -221,6 +232,41 @@ class DescribeDocument(object):
         text = 'foobar\rbarfoo'
         return document, text, p_, r_
 
+    @pytest.fixture
+    def init_fixture(self, docx_, open_):
+        return docx_, open_
+
+    @pytest.fixture
+    def num_part_get_fixture(self, document, document_part_, numbering_part_):
+        document_part_.part_related_by.return_value = numbering_part_
+        return document, document_part_, numbering_part_
+
+    @pytest.fixture
+    def open_fixture(self, docx_, Package_, package_, document_part_):
+        return docx_, Package_, package_, document_part_
+
+    @pytest.fixture
+    def paragraphs_fixture(self, document, paragraphs_):
+        return document, paragraphs_
+
+    @pytest.fixture
+    def save_fixture(self, request, open_, package_):
+        file_ = instance_mock(request, str)
+        document = Document()
+        return document, package_, file_
+
+    @pytest.fixture
+    def tables_fixture(self, document, tables_):
+        return document, tables_
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def add_paragraph_(self, request, p_):
+        return method_mock(
+            request, Document, 'add_paragraph', return_value=p_
+        )
+
     @pytest.fixture
     def default_docx_(self, request):
         return var_mock(request, 'docx.api._default_docx_path')
@@ -236,11 +282,13 @@ class DescribeDocument(object):
         return Document()
 
     @pytest.fixture
-    def document_part_(self, request, p_, paragraphs_, table_, tables_):
+    def document_part_(
+            self, request, p_, paragraphs_, section_, table_, tables_):
         document_part_ = instance_mock(
             request, DocumentPart, content_type=CT.WML_DOCUMENT_MAIN
         )
         document_part_.add_paragraph.return_value = p_
+        document_part_.add_section.return_value = section_
         document_part_.add_table.return_value = table_
         document_part_.paragraphs = paragraphs_
         document_part_.tables = tables_
@@ -250,10 +298,6 @@ class DescribeDocument(object):
     def docx_(self, request):
         return instance_mock(request, str)
 
-    @pytest.fixture
-    def init_fixture(self, docx_, open_):
-        return docx_, open_
-
     @pytest.fixture
     def inline_shapes_(self, request):
         return instance_mock(request, InlineShapes)
@@ -264,11 +308,6 @@ class DescribeDocument(object):
         document_part_.part_related_by.side_effect = KeyError
         return document, NumberingPart_, document_part_, numbering_part_
 
-    @pytest.fixture
-    def num_part_get_fixture(self, document, document_part_, numbering_part_):
-        document_part_.part_related_by.return_value = numbering_part_
-        return document, document_part_, numbering_part_
-
     @pytest.fixture
     def NumberingPart_(self, request, numbering_part_):
         NumberingPart_ = class_mock(request, 'docx.api.NumberingPart')
@@ -286,10 +325,6 @@ class DescribeDocument(object):
             return_value=(document_part_, package_)
         )
 
-    @pytest.fixture
-    def open_fixture(self, docx_, Package_, package_, document_part_):
-        return docx_, Package_, package_, document_part_
-
     @pytest.fixture
     def p_(self, request, r_):
         p_ = instance_mock(request, Paragraph)
@@ -312,19 +347,17 @@ class DescribeDocument(object):
     def paragraphs_(self, request):
         return instance_mock(request, list)
 
-    @pytest.fixture
-    def paragraphs_fixture(self, document, paragraphs_):
-        return document, paragraphs_
-
     @pytest.fixture
     def r_(self, request):
         return instance_mock(request, Run)
 
     @pytest.fixture
-    def save_fixture(self, request, open_, package_):
-        file_ = instance_mock(request, str)
-        document = Document()
-        return document, package_, file_
+    def section_(self, request):
+        return instance_mock(request, Section)
+
+    @pytest.fixture
+    def start_type_(self, request):
+        return instance_mock(request, int)
 
     @pytest.fixture
     def StylesPart_(self, request, styles_part_):
@@ -354,7 +387,3 @@ class DescribeDocument(object):
     @pytest.fixture
     def tables_(self, request):
         return instance_mock(request, list)
-
-    @pytest.fixture
-    def tables_fixture(self, document, tables_):
-        return document, tables_
