@@ -154,13 +154,19 @@ class DescribeRun(object):
 
     def it_knows_its_underline_type(self, underline_get_fixture):
         run, expected_value = underline_get_fixture
-        assert run.underline == expected_value
+        assert run.underline is expected_value
 
     def it_can_change_its_underline_type(self, underline_set_fixture):
         run, underline, expected_xml = underline_set_fixture
         run.underline = underline
         assert run._r.xml == expected_xml
 
+    def it_raises_on_assign_invalid_underline_type(
+            self, underline_raise_fixture):
+        run, underline = underline_raise_fixture
+        with pytest.raises(ValueError):
+            run.underline = underline
+
     def it_can_add_text(self, add_text_fixture):
         run, text_str, expected_xml, Text_ = add_text_fixture
         _text = run.add_text(text_str)
@@ -375,6 +381,13 @@ class DescribeRun(object):
         run = Run(r)
         return run, expected_prop_value
 
+    @pytest.fixture(params=['foobar', 42, 'single'])
+    def underline_raise_fixture(self, request):
+        underline = request.param
+        r = self.r_bldr_with_underline(None).element
+        run = Run(r)
+        return run, underline
+
     @pytest.fixture(params=[
         (None,     True,                'single'),
         (None,     False,               'none'),
